@@ -8,13 +8,13 @@ def es_get_result_to_dict(es_result: dict) -> dict:
     A typical es result
     {
     "_index": "local-bdating",
-    "_id": "0x7bf572eF922A79d5e01d064506f682caaCa0abCd:producer",
+    "_id": "0x7bf572eF922A79d5e01d064506f682caaCa0abCd:provider",
     "_version": 1,
     "_seq_no": 0,
     "_primary_term": 1,
     "found": true,
     "_source": {
-      "type": "producer",
+      "type": "provider",
       "wallet": "0x7bf572eF922A79d5e01d064506f682caaCa0abCd",
       "address": "10809 Mercedes Loaf Apt. 552\nNancyborough, ID 01277",
       "location": [
